@@ -16,32 +16,31 @@
 
 #include "kget_interface.h"
 
-#include <KActionCollection>
-#include <KToggleAction>
-#include <KActionMenu>
-#include <KIconLoader>
-#include <KComponentData>
-#include <KLocalizedString>
-#include <KMessageBox>
-#include <QMenu>
-#include <KRun>
 #include <QIcon>
-#include <KToolInvocation>
-#include <KGenericFactory>
-#include <KProtocolInfo>
-#include <KFileItem>
-#include <KDE/KParts/Part>
-#include <KDE/KParts/PartManager>
-#include <KDE/KParts/HtmlExtension>
-#include <KDE/KParts/FileInfoExtension>
-
+#include <QMenu>
 #include <QDBusConnection>
 
+#include <KActionCollection>
+#include <KActionMenu>
+#include <KFileItem>
+#include <KIconLoader>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KPluginFactory>
+#include <KProtocolInfo>
+#include <KParts/FileInfoExtension>
+#include <KParts/HtmlExtension>
+#include <KParts/Part>
+#include <KParts/PartManager>
+#include <KParts/ReadOnlyPart>
+#include <KParts/SelectorInterface>
+#include <KRun>
+#include <KToggleAction>
+#include <KToolInvocation>
 
 #define QL1S(x)   QLatin1String(x)
 
 K_PLUGIN_FACTORY(KGetPluginFactory, registerPlugin<KGetPlugin>();)
-K_EXPORT_PLUGIN(KGetPluginFactory("kgetplugin"))
 
 static QWidget* partWidget(QObject* obj)
 {
@@ -206,7 +205,7 @@ void KGetPlugin::getLinks(bool selectedOnly)
                     attr = QL1S("src");
                 else if (element.hasAttribute(QL1S("data")))
                     attr = QL1S("data");
-                const QUrl resolvedUrl (baseUrl.resolved(element.attribute(attr)));
+                const QUrl resolvedUrl (baseUrl.resolved(QUrl(element.attribute(attr))));
                 // Only select valid and non-local links for download...
                 if (resolvedUrl.isValid() && !resolvedUrl.isLocalFile() && !resolvedUrl.host().isEmpty()) {
                     if (element.hasAttribute(QL1S("type")))
