@@ -22,6 +22,7 @@
 #include <QMouseEvent>
 #include <QPainter>
 #include <QDate>
+#include <QPainterPath>
 
 #include <QDebug>
 #include <kio/global.h>
@@ -193,8 +194,8 @@ void TransferHistoryItemDelegate::slotDownload()
 {
    const QAbstractItemModel *model = static_cast <const QAbstractItemModel *> (m_selectedIndex.model());
 
-    NewTransferDialogHandler::showNewTransferDialog(model->data(m_selectedIndex,
-                                                    TransferHistoryCategorizedDelegate::RoleUrl).toString());
+    NewTransferDialogHandler::showNewTransferDialog(QUrl(model->data(m_selectedIndex,
+                                                                     TransferHistoryCategorizedDelegate::RoleUrl).toString()));
 }
 
 void TransferHistoryItemDelegate::slotDeleteTransfer()
