@@ -39,7 +39,7 @@ TransferSettingsDialog::TransferSettingsDialog(QWidget *parent, TransferHandler
     ui.downloadSpin->setValue(m_transfer->downloadLimit(Transfer::VisibleSpeedLimit));
     ui.uploadSpin->setValue(m_transfer->uploadLimit(Transfer::VisibleSpeedLimit));
     ui.ratioSpin->setValue(m_transfer->maximumShareRatio());
-    ui.destination->setUrl(m_transfer->directory().toString());
+    ui.destination->setUrl(m_transfer->directory());
     ui.destination->lineEdit()->setReadOnly(true);
     ui.rename->setIcon(QIcon::fromTheme("edit-rename"));
     ui.mirrors->setIcon(QIcon::fromTheme("download"));
@@ -54,7 +54,7 @@ TransferSettingsDialog::TransferSettingsDialog(QWidget *parent, TransferHandler
         ui.treeView->setModel(m_proxy);
         ui.treeView->sortByColumn(0, Qt::AscendingOrder);
 
-        QByteArray loadedState = QByteArray::fromBase64(Settings::transferSettingsHeaderState().toAscii());
+        QByteArray loadedState = QByteArray::fromBase64(Settings::transferSettingsHeaderState().toLatin1());
         if (!loadedState.isEmpty()) {
             ui.treeView->header()->restoreState(loadedState);
         } else {
